/* ============================================================
 * Author: M. Asselstine <asselsm@gmail.com>
 * Date  : 05-08-2005
 * Description : main
 * 
 * Copyright 2005 by M. Asselstine

 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * ============================================================ */


#include <kapplication.h>
#include <dcopclient.h>
#include <kaboutdata.h>
#include <kcmdlineargs.h>
#include <klocale.h>

#include "kflickr.h"

static const char description[] =
    I18N_NOOP("A Flickr uploader for KDE");

static const char version[] = "0.9.1";

static KCmdLineOptions options[] =
{
    { "+[URL(s)]", I18N_NOOP("photo(s) to open"), 0 },
    KCmdLineLastOption
};

int main(int argc, char **argv)
{
    KAboutData about("kflickr", I18N_NOOP("kflickr"), version, description,
                     KAboutData::License_GPL, "(C) 2005 M. Asselstine", 0, 0, "asselsm@gmail.com");
    about.addAuthor( "M. Asselstine", 0, "asselsm@gmail.com" );
    KCmdLineArgs::init(argc, argv, &about);
    KCmdLineArgs::addCmdLineOptions( options );
    KApplication app;
    kflickr *mainWin = 0;

    // register ourselves as a dcop client
    app.dcopClient()->registerAs(app.name(), false);
    
    // see if we are starting with session management
    if (app.isRestored())
    {
        RESTORE(kflickr);
    }
    else
    {
        // no session.. just start up normally
        KCmdLineArgs *args = KCmdLineArgs::parsedArgs();

        // create the main windows etc.
        mainWin = new kflickr;
        app.setMainWidget( mainWin );
        mainWin->show();
        
        // add any photos passed from the command line
        for( int i = 0; i < args->count(); i++ )
        {
            mainWin->load( args->url(i) );
        }

        args->clear();
    }

    // mainWin has WDestructiveClose flag by default, so it will delete itself.
    return app.exec();
}

